pub struct ConsNode<T> { /* private fields */ }Available on crate features
collections and cons only.Expand description
Largely intended as an internal type, these nodes are returned by ConsBranch::into_iter_rc
because the interior of the Rc can’t be unwrapped in place.
To help using these nodes, a couple of useful traits have been implemented:
Deref<Target = T> for ConsNode<T>for accessing the contained value.Into<ConsBranch> for Rc<ConsNode<T>>for creating a newConsBranchfrom anRc.
Note that cloning a ConsNode directly is not cheap as it is with ConsBranch because
the node contains the value (of type T) itself.