pub struct ConsNode<T> { /* private fields */ }Available on crate features
collections and cons only.Expand description
Largely intended as an internal type, these nodes are returned by [ConsTree::into_iter_rc]
because the interior of the Rc can’t be unwrapped in place.
To help using these nodes, a couple of useful traits have been implemented:
Deref<Target = T> for ConsTreeNode<T>for accessing the contained value.Into<ConsTree> for Rc<ConsTreeNode<T>>for creating a new [ConsTree] from anRc.
Note that cloning a ConsTreeNode directly is not cheap as it is with [ConsTree] because
the node contains the value (of type T) itself.